#
# spec file for package audio-recorder
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           audio-recorder
Version:        3.2.3
Release:        bp154.1.87
Summary:        An audio recorder application for the GNOME 2/3
License:        GPL-3.0
Group:          Productivity/Multimedia/Sound/Utilities
Url:            https://launchpad.net/~audio-recorder
Source:         https://launchpad.net/~audio-recorder/+archive/ubuntu/ppa/+sourcefiles/audio-recorder/%{version}~hirsute/audio-recorder_%{version}~hirsute.tar.gz
# PATCH-FIX-OPENSUSE audio-recorder-correct-desktop-menu.patch badshah400@gmail.com -- Fixes the .desktop file by removing unity related tags from it.
Patch0:         audio-recorder-correct-desktop-menu.patch
BuildRequires:  autoconf
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(appindicator3-0.1) >= 0.3
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 1.4
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpulse)
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-ugly

%description
Audio-recorder allows you to record music or audio to
a file. It can record audio from your system's soundcard,
microphones, browsers and webcams. Put simply: if it plays out of
your loudspeakers, you can record it.

It has an advanced timer that can:
* Start, stop or pause recording at a given clock time.
* Start, stop or pause after a time period.
* Stop when the recorded file size exceeds a limit.
* Start recording on voice or sound.
* Stop or pause recording on "silence".

The recording can be automatically controlled by:
* RhythmBox audio player.
* Banshee audio player.
* Amarok and other MPRIS compatible players.
* Skype. It can automatically record all your Skype calls without
  any user interaction.

This program supports several audio (output) formats such as Ogg Vorbis
audio, FLAC, MP3 and WAV.

User can also control the recorder from command line with
--command <arg> option.

%lang_package

%prep
%setup -q -n trunk
%patch0 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}%{_datadir}
%find_lang %{name} %{?no_lang_C}

%post
%glib2_gsettings_schema_post

%postun
%glib2_gsettings_schema_postun

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/scalable/*/audio-recorder*.svg
%{_datadir}/pixmaps/%{name}
%{_datadir}/glib-2.0/schemas/org.gnome.audio-recorder.gschema.xml
%{_mandir}/man1/%{name}.1%{ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.2.3
  * The recording must end with EOS message,
    otherwise MPEG 4 Audio (.m4a) files becomes invalid.
  * Fixed export to M4A / AAC with new gstreamer
  * Fixed a minor issue in settings-pipe.c
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep  9 2019 ukbeast89@protonmail.com
- Update to 3.0.5:
  + Create audio folder even it has many subpaths.
* Wed Aug  8 2018 rpm@fthiessen.de
- Update to 2.1.3:
  + Fix in rec_stop_recording(...) to avoid possible blockage.
  + Fix to support longer filenames and filenames with bad
    characters.
* Tue Nov 21 2017 jengelh@inai.de
- Update descriptions.
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to 2.0.2:
  + See ChangeLog for full details
- Rebase audio-recorder-correct-desktop-menu.patch
- Drop audio-recorder-gtk-3.16.patch: merged upstream
* Tue May  5 2015 dimstar@opensuse.org
- Update to version 1.6-2:
  + See ChangeLog for full details.
- Add pkgconfig(gstreamer-pbutils-1.0) and
  pkgconfig(appindicator3-0.1) BuildRequires: new dependecies.
- Add audio-recorder-gtk-3.16.patch: Add GTK 3.16 compatibility.
- Drop audio-recorder-automake.patch: fixed upstream.
* Thu Oct  9 2014 dimstar@opensuse.org
- Add audio-recorder-automake.patch: fix the order of commands in
  configure.ac.
* Wed Jan 22 2014 dimstar@opensuse.org
- Update to version 1.4-1:
  + lp#1258822: Timer does not stop recording in some rare cases.
- Changes from version 1.4:
  + Replaced fixed size icons 16x16,...,64x64 with scalable svg
    images.
  + Replaced also some images with
    pixmap/audio-recorder-off-dot.svg, audio-recorder-on-dot.svg,
    audio-recorder-paused-dot.svg.
- Changes from version 1.1:
  + Migrated dbus-skype.c to GDBus intrerface.
  + Removed dependency to dbus-glib-1 library.
  + Removed skype-service.[ch] and skype-service-object-glue.h from
    the project.
- Add %%desktop_database_post/%%desktop_database_postun to scriptlets
  in order to update the desktop database.
- Add desktop-file-utils BuildRequires: needed for the above macros
  to be defined.
- Drop pkgconfig(libgnome-media-profiles-3.0) and
  pkgconfig(dbus-glib-1) BuildRequires: no longer required.
* Wed Mar 13 2013 p.drouand@gmail.com
- Update to version 0.9.8:
  + lp#1074928: Audio-recorder could not find configuration values
    (in dconf) and exited.
- Changes from version 0.9.7:
  + Audio-recorder will now remember lastly used media-players.
  + New/changed key in data/org.gnome.audio-recorder.gschema.xml.
- Changes from version 0.9.5:
  + Moving to Gstreamer 1.0.
- Changes from verion 0.9.4:
  + Complete the port to GTK3.
- Changes from version 0.9.3:
  + Improved timer and VAD-modules.
  + Better gst-pipeline.
- Replace Requires and BuildRequires for GStreamer 1.0 port:
  + Old BuildRequires: pkgconfig(gstreamer-0.10),
    pkgconfig(gstreamer-base-0.10) and
    pkgconfig(gstreamer-interfaces-0.10),
  + Old Requires: gstreamer-0_10-plugins-bad,
    gstreamer-0_10-plugins-base, gstreamer-0_10-plugins-good and
    gstreamer-0_10-plugins-ugly
  + New BuildRequires: pkgconfig(gstreamer-1.0)
  + New Requires: gstreamer-plugins-bad, gstreamer-plugins-base,
    gstreamer-plugins-good and gstreamer-plugins-ugly.
- Replace pkgconfig(gtk+-2.0) BuildRequires with
  pkgconfig(gtk+-3.0), following upstream.
- Replace pkgconfig(gconf-2.0) BuildRequires with pkgconfig(dconf),
  following upstreams port to GSettings.
- Drop audio-recorder-gio-gdesktopappinfo-header.patch: as it's
  only applied on openSUSE <= 12.1, it became useless after the
  port of audio-recorder to GStreamer 1.0, which only exists since
  openSUSE 12.3.
* Sun Apr 29 2012 badshah400@gmail.com
- Initial package, version 0.9.1
  Add audio-recorder-correct-desktop-menu.patch and
  audio-recorder-gio-gdesktopappinfo-header.patch
